@@ -419,23 +419,44 @@ class TISProtocolHandler:
         )
 
     def generate_floor_on_off_packet(self, entity, state: int) -> TISPacket:
+
+        if entity.heater_number == 0:
+            add_bytes=[(entity.heater_number), 0x14, state]
+
+        if entity.heater_number == 1:
+            add_bytes=[(entity.heater_number + 0x22), 0x14, state]
+        
+        if entity.heater_number >= 2:
+            add_bytes=[0x2E, (entity.heater_number) + 1, 0x03, state]
+        
         return TISPacket(
             device_id=entity.device_id,
             operation_code=self.OPERATION_FLOOR_CONTROL,
             source_ip=entity.api.host,
             destination_ip=entity.gateway,
-            additional_bytes=[(entity.heater_number + 0x22), 0x14, state],
+            additional_bytes=add_bytes            
+            
         )
 
     def generate_floor_set_temp_packet(
         self, entity, target_temperature: int
     ) -> TISPacket:
+        
+        if entity.heater_number == 0:
+            add_bytes=[(entity.heater_number), 0x18, target_temperature]
+
+        if entity.heater_number == 1:
+            add_bytes=[(entity.heater_number + 0x22), 0x18, target_temperature]
+        
+        if entity.heater_number >= 2:
+            add_bytes=[0x2E, (entity.heater_number) + 1, 0x04, target_temperature]
+    
         return TISPacket(
             device_id=entity.device_id,
             operation_code=self.OPERATION_FLOOR_CONTROL,
             source_ip=entity.api.host,
             destination_ip=entity.gateway,
-            additional_bytes=[(entity.heater_number + 0x22), 0x18, target_temperature],
+            additional_bytes=add_bytes,
         )
 
     def generate_update_analog_packet(self, entity) -> TISPacket:
